//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

#include <unistd.h>
#include <nx/WSDnxAppDev.h>
#include <nx/WSDnxColor.h>
#include <nx/WSDnxMouse.h>
#include <WSCcolorSet.h>
#include <WSCimageSet.h>
#include <WSDdev.h>
#include <nx/WSDnxDraw.h>

extern int main1(int argc,char** argv);

int WSGFwsMain(int argc,char** argv){

  _dbprintf_init();
dbprintf("Main.cpp: MAIN() %s:%d start.\n",__FILE__,__LINE__);
  main1(argc,argv);
  WSDappDev* app = WSGIappDev();
  WSDnxAppDev* nxApp = (WSDnxAppDev*)app->cast("WSDnxAppDev");
  if (argc != 0){
    nxApp->setInitPrm(argc,argv);
  }

dbprintf("Main.cpp: main() %s:%d here1.\n",__FILE__,__LINE__);
  nxApp->execInitHandler();
dbprintf("Main.cpp: main() %s:%d here2.\n",__FILE__,__LINE__);
  nxApp->handleEvents();
dbprintf("Main.cpp: main() %s:%d done.\n",__FILE__,__LINE__);
  return 0;
}
#ifndef NO_MAIN_FUNCTION
int main(int argc,char** argv){
  return WSGFwsMain(argc,argv);
}
#endif

